#ifndef CONCEPTSDIALOG_H
#define CONCEPTSDIALOG_H

#include <QDialog>
#include <QModelIndex>

class ConceptsDialog : public QDialog
{
        Q_OBJECT
 public:
        ConceptsDialog(QWidget *parent = 0,
                       Qt::WindowFlags f = 0);

 signals:
        void newConceptSelected();
        void conceptDetailsSelected(const QModelIndex &index);
};
#endif
